# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

* Nothing yet

## [0.0.9]

* Migrate api out of `__init__.py`
* Move dependency pandas-stubs to developer dependencies
* Update dependency pandas to <=1.5.1
* Update dependency pyarrow to v10
* Update dependency pydantic to <=1.10.1
* Update dependency scipy to <=1.9.1

## [0.0.8]

* Update pandas-stubs requirement from ~=1.4.2.220626 to ~=1.4.3.220801
* Update pandas requirement from ~=1.4.2 to ~=1.4.3
* Update pyarrow requirement from ~=8.0.0 to ~=9.0.0
* Update scipy requirement from ~=1.8.1 to ~=1.9.0

## [0.0.7]

* Update dynaconf requirement from ~=3.1.8 to ~=3.1.9 by @dependabot in <https://github.com/blakeNaccarato/propshop/pull/17>
* Update pandas-stubs requirement from ~=1.2.0.58 to ~=1.4.2

## [0.0.6]

* Update openpyxl requirement from ~=3.0.9 to ~=3.0.10 (<https://github.com/blakeNaccarato/propshop/pull/15>)
* Update pydantic requirement from ~=1.9.0 to ~=1.9.1 (<https://github.com/blakeNaccarato/propshop/pull/14>)

## [0.0.5]

* Update scipy requirement from ~=1.8.0 to ~=1.8.1 (<https://github.com/blakeNaccarato/propshop/pull/13>)
* Don't use star import in `__init__.py`

## [0.0.4]

* Fix path bug on Windows

## [0.0.3]

* Update pyarrow requirement from ~=7.0.0 to ~=8.0.0 (<https://github.com/blakeNaccarato/propshop/pull/12>)

## [0.0.2]

* App folder will now be properly created.

## [0.0.1]

* Support interpolating temperature to get thermal conductivity of copper
* User must supply the property file

[Unreleased]: https://github.com/blakeNaccarato/propshop/compare/0.0.9...HEAD
[0.0.9]: https://github.com/blakeNaccarato/propshop/compare/0.0.8...0.0.9
[0.0.8]: https://github.com/blakeNaccarato/propshop/compare/0.0.7...0.0.8
[0.0.7]: https://github.com/blakeNaccarato/propshop/compare/0.0.6...0.0.7
[0.0.6]: https://github.com/blakeNaccarato/propshop/compare/0.0.5...0.0.6
[0.0.5]: https://github.com/blakeNaccarato/propshop/compare/0.0.4...0.0.5
[0.0.4]: https://github.com/blakeNaccarato/propshop/compare/0.0.3...0.0.4
[0.0.3]: https://github.com/blakeNaccarato/propshop/compare/0.0.2...0.0.3
[0.0.2]: https://github.com/blakeNaccarato/propshop/compare/0.0.1...0.0.2
[0.0.1]: https://github.com/blakeNaccarato/propshop/releases/tag/0.0.1
